Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(292)

Unified Diff: content/browser/certificate_manager_model.h

Issue 6580058: NSS: Unlock crypto devices when populating cert manager. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review changes Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/certificate_manager_model.h
diff --git a/content/browser/certificate_manager_model.h b/content/browser/certificate_manager_model.h
index f134a682327234b08924c0d389429c78727b240d..38be1e436be3fa1cfb26e5dad37bf82122953120 100644
--- a/content/browser/certificate_manager_model.h
+++ b/content/browser/certificate_manager_model.h
@@ -43,9 +43,10 @@ class CertificateManagerModel {
// Accessor for read-only access to the underlying CertDatabase.
const net::CertDatabase& cert_db() const { return cert_db_; }
// Refresh the list of certs. Following this call, the observer
// CertificatesRefreshed method will be called so the view can call
// FilterAndBuildOrgGroupingMap as necessary to refresh its tree views.
void Refresh();
// Fill |map| with the certificates matching |filter_type|.
@@ -98,6 +99,10 @@ class CertificateManagerModel {
bool Delete(net::X509Certificate* cert);
private:
+ // Callback used by Refresh() for when the cert slots have been unlocked.
+ // This method does the actual refreshing.
+ void RefreshSlotsUnlocked();
+
net::CertDatabase cert_db_;
net::CertificateList cert_list_;
@@ -43,9 +43,10 @@ class CertificateManagerModel {
// Accessor for read-only access to the underlying CertDatabase.
const net::CertDatabase& cert_db() const { return cert_db_; }
- // Refresh the list of certs. Following this call, the observer
- // CertificatesRefreshed method will be called so the view can call
- // FilterAndBuildOrgGroupingMap as necessary to refresh its tree views.
+ // Trigger a refresh of the list of certs, unlock any slots if necessary.
+ // Following this call, the observer CertificatesRefreshed method will be
+ // called so the view can call FilterAndBuildOrgGroupingMap as necessary to
+ // refresh its tree views.
void Refresh();
// Fill |map| with the certificates matching |filter_type|.

Powered by Google App Engine
This is Rietveld 408576698